emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/lisp/emacs-lisp/easy-mmode.el,v


From: Chong Yidong
Subject: [Emacs-diffs] Changes to emacs/lisp/emacs-lisp/easy-mmode.el,v
Date: Sat, 03 Feb 2007 17:26:28 +0000

CVSROOT:        /sources/emacs
Module name:    emacs
Changes by:     Chong Yidong <cyd>      07/02/03 17:26:28

Index: easy-mmode.el
===================================================================
RCS file: /sources/emacs/emacs/lisp/emacs-lisp/easy-mmode.el,v
retrieving revision 1.81
retrieving revision 1.82
diff -u -b -r1.81 -r1.82
--- easy-mmode.el       21 Jan 2007 02:44:24 -0000      1.81
+++ easy-mmode.el       3 Feb 2007 17:26:28 -0000       1.82
@@ -271,9 +271,11 @@
 ;;;
 
 ;;;###autoload
-(defalias 'easy-mmode-define-global-mode 'define-global-minor-mode)
+(defalias 'easy-mmode-define-global-mode 'define-globalized-minor-mode)
 ;;;###autoload
-(defmacro define-global-minor-mode (global-mode mode turn-on &rest keys)
+(defalias 'define-global-minor-mode 'define-globalized-minor-mode)
+;;;###autoload
+(defmacro define-globalized-minor-mode (global-mode mode turn-on &rest keys)
   "Make a global mode GLOBAL-MODE corresponding to buffer-local minor MODE.
 TURN-ON is a function that will be called with no args in every buffer
   and that should try to turn MODE on if applicable for that buffer.
@@ -283,7 +285,7 @@
   which see.  In particular, :group specifies the custom group.
   The most useful keywords are those that are passed on to the
   `defcustom'.  It normally makes no sense to pass the :lighter
-  or :keymap keywords to `define-global-minor-mode', since these
+  or :keymap keywords to `define-globalized-minor-mode', since these
   are usually passed to the buffer-local version of the minor mode.
 
 If MODE's set-up depends on the major mode in effect when it was
@@ -348,7 +350,7 @@
           (with-current-buffer buf
             (if ,global-mode (,turn-on) (when ,mode (,mode -1))))))
 
        ;; Autoloading define-global-minor-mode autoloads everything
        ;; up-to-here.
        :autoload-end
 
@@ -348,7 +350,7 @@
             (if ,global-mode (,turn-on) (when ,mode (,mode -1))))))
 
-       ;; Autoloading define-global-minor-mode autoloads everything
+       ;; Autoloading define-globalized-minor-mode autoloads everything
        ;; up-to-here.
        :autoload-end




reply via email to

[Prev in Thread] Current Thread [Next in Thread]